==> foundry_platform_sdk-0.56.0.tar.gz: foundry_platform_sdk-0.56.0/foundry/v2/third_party_applications/errors/_upload_snapshot_version_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.third_party_applications.models._third_party_application_rid import (
    ThirdPartyApplicationRid,
)  # NOQA


class UploadSnapshotVersionPermissionDeniedParameters(TypedDict):
    """Could not uploadSnapshot the Version."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    thirdPartyApplicationRid: ThirdPartyApplicationRid
    """An RID identifying a third-party application created in Developer Console."""


@dataclass
class UploadSnapshotVersionPermissionDenied(PalantirRPCException):
    name: Literal["UploadSnapshotVersionPermissionDenied"]
    parameters: UploadSnapshotVersionPermissionDeniedParameters
    error_instance_id: str


__all__ = ["UploadSnapshotVersionPermissionDenied"]

==> foundry_platform_sdk-0.91.0.tar.gz: foundry_platform_sdk-0.91.0/foundry/v2/third_party_applications/errors/_upload_snapshot_version_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import PermissionDeniedError
from foundry.v2.third_party_applications.models._third_party_application_rid import (
    ThirdPartyApplicationRid,
)  # NOQA


class UploadSnapshotVersionPermissionDeniedParameters(TypedDict):
    """Could not uploadSnapshot the Version."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    thirdPartyApplicationRid: ThirdPartyApplicationRid
    """An RID identifying a third-party application created in Developer Console."""


@dataclass
class UploadSnapshotVersionPermissionDenied(PermissionDeniedError):
    name: Literal["UploadSnapshotVersionPermissionDenied"]
    parameters: UploadSnapshotVersionPermissionDeniedParameters
    error_instance_id: str


__all__ = ["UploadSnapshotVersionPermissionDenied"]
